"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getMuiClasses = exports.capitalise = exports.getTransitionDirection = exports.muiClasses = void 0;

var _constants = require("../utils/constants");

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var DIRECTION = {
  right: 'left',
  left: 'right',
  bottom: 'up',
  top: 'down'
};
var muiClasses = {
  root: {},
  anchorOriginTopCenter: {},
  anchorOriginBottomCenter: {},
  anchorOriginTopRight: {},
  anchorOriginBottomRight: {},
  anchorOriginTopLeft: {},
  anchorOriginBottomLeft: {}
};
/**
 * returns transition direction according the the given anchor origin
 * @param {object} anchorOrigin
 */

exports.muiClasses = muiClasses;

var getTransitionDirection = function getTransitionDirection() {
  var anchorOrigin = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : _constants.defaultAnchorOrigin;

  if (anchorOrigin.horizontal !== 'center') {
    return DIRECTION[anchorOrigin.horizontal];
  }

  return DIRECTION[anchorOrigin.vertical];
};
/**
 * Capitalises a piece of string
 * @param {string} text
 */


exports.getTransitionDirection = getTransitionDirection;

var capitalise = function capitalise(text) {
  return text.charAt(0).toUpperCase() + text.slice(1);
};
/**
 * Filteres classes object and returns the keys that are allowed
 * in material-ui snackbar classes prop
 * @param {object} classes
 */


exports.capitalise = capitalise;

var getMuiClasses = function getMuiClasses(classes) {
  return Object.keys(classes).filter(function (key) {
    return muiClasses[key] !== undefined;
  }).reduce(function (obj, key) {
    return _objectSpread({}, obj, _defineProperty({}, key, classes[key]));
  }, {});
};

exports.getMuiClasses = getMuiClasses;